@@ -29,7 +29,7 @@ except ImportError:
 from pcbdraw.unit import read_resistance
 import svgpathtools # type: ignore
 from lxml import etree, objectify # type: ignore
-from pcbnewTransition import KICAD_VERSION, isV6, pcbnew # type: ignore
+from pcbnewTransition import KICAD_VERSION, isV6, isV7, pcbnew # type: ignore
 
 T = TypeVar("T")
 Numeric = Union[int, float]
@@ -41,6 +41,8 @@ PKG_BASE = os.path.dirname(__file__)
 
 etree.register_namespace("xlink", "http://www.w3.org/1999/xlink")
 
+LEGACY_KICAD = not isV6() and not isV7()
+
 default_style = {
     "copper": "#417e5a",
     "board": "#4ca06c",
@@ -107,7 +109,10 @@ class SvgPathItem:
     def is_same(p1: Point, p2: Point) -> bool:
         dx = p1[0] - p2[0]
         dy = p1[1] - p2[1]
-        return math.sqrt(dx*dx+dy*dy) < 100
+        pseudo_distance = dx*dx + dy*dy
+        if isV7():
+            return pseudo_distance < 0.01 ** 2
+        return pseudo_distance < 100 ** 2
 
     def format(self, first: bool) -> str:
         ret = ""
@@ -581,7 +586,7 @@ def collect_holes(board: pcbnew.BOARD) -> List[Hole]:
                 orientation=pad.GetOrientation(),
                 drillsize=(drs.x, drs.y)
             ))
-    via_type = pcbnew.VIA if not isV6(KICAD_VERSION) else pcbnew.PCB_VIA
+    via_type = pcbnew.VIA if LEGACY_KICAD else pcbnew.PCB_VIA
     for track in board.GetTracks():
         if not isinstance(track, via_type):
             continue
@@ -1013,8 +1018,15 @@ class PcbPlotter():
 
         self.yield_warning: Callable[[str, str], None] = lambda tag, msg: None # Handle warnings
 
-        self.ki2svg = self._ki2svg_v6 if isV6(KICAD_VERSION) else self._ki2svg_v5
-        self.svg2ki = self._svg2ki_v6 if isV6(KICAD_VERSION) else self._svg2ki_v5
+        if isV7():
+            self.ki2svg = self._ki2svg_v7
+            self.svg2ki = self._svg2ki_v7
+        elif isV6():
+            self.ki2svg = self._ki2svg_v6
+            self.svg2ki = self._svg2ki_v6
+        else:
+            self.ki2svg = self._ki2svg_v5
+            self.svg2ki = self._svg2ki_v5
 
     @property
     def svg_precision(self) -> int:
@@ -1192,8 +1204,10 @@ class PcbPlotter():
                 # Method does not exist in older versions of KiCad
                 pass
             popt.SetTextMode(pcbnew.PLOT_TEXT_MODE_STROKE)
-            if isV6(KICAD_VERSION):
+            if isV6():
                 popt.SetSvgPrecision(self.svg_precision, False)
+            if isV7():
+                popt.SetSvgPrecision(self.svg_precision)
             for action in to_plot:
                 if len(action.layers) == 0:
                     continue
@@ -1232,6 +1246,12 @@ class PcbPlotter():
     def _svg2ki_v5(self, x: float) -> int:
         return dmil2ki(x)
 
+    def _svg2ki_v7(self, x: float) -> int:
+        return int(pcbnew.FromMM(x))
+
+    def _ki2svg_v7(self, x: int) -> float:
+        return float(pcbnew.ToMM(x))
+
     def _shrink_svg(self, svg: etree.ElementTree, margin: int) -> None:
         """
         Shrink the SVG canvas to the size of the drawing. Add margin in
